@@ -55,7 +55,8 @@ class Connection(Statement):
     src: str
     dst: str
     text: str
-
+    reversed: bool = False
+    relaxed: bool = False
 
 @dataclass
 class Style(Statement):
